@@ -15,7 +15,13 @@ def test_ready():
         assert response.json() == {"status": "ok"}
 
 
-{% if cookiecutter.redis == "yes" %}
+def test_ready_invalid():
+    with TestClient(app) as client:
+        response = client.get("/api/ready/123")
+        assert response.status_code == 404
+{%- if cookiecutter.redis == "yes" %}
+
+
 def test_ready_invalid_with_redis():
     settings.USE_REDIS = True
 
@@ -26,13 +32,7 @@ def test_ready_invalid_with_redis():
             "error": {
                 "code": 502,
                 "message": "Could not connect to Redis",
-                "status": "BAD_GATEWAY"
+                "status": "BAD_GATEWAY",
             }
         }
-{% endif %}
-
-
-def test_ready_invalid():
-    with TestClient(app) as client:
-        response = client.get("/api/ready/123")
-        assert response.status_code == 404
+{% endif %}
\ No newline at end of file
